==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicecloudaccess/cloudaccesses/cloudaccess/DefaultAuthorizedSites.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicecloudaccess.cloudaccesses.cloudaccess;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicecloudaccess.cloudaccesses.cloudaccess.authorizedsites.AuthorizedSite;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of authorizedSites.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAuthorizedSites extends InnerModelObject implements AuthorizedSites {
    protected List<AuthorizedSite> authorizedSite;

    @Override
    public List<AuthorizedSite> authorizedSite() {
        return authorizedSite;
    }

    @Override
    public void authorizedSite(List<AuthorizedSite> authorizedSite) {
        this.authorizedSite = authorizedSite;
    }

    @Override
    public void addToAuthorizedSite(AuthorizedSite addTo) {
        if (authorizedSite == null) {
            authorizedSite = new ArrayList<>();
        }
        authorizedSite.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(authorizedSite);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAuthorizedSites) {
            DefaultAuthorizedSites other = (DefaultAuthorizedSites) obj;
            return
                Objects.equals(authorizedSite, other.authorizedSite);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("authorizedSite=" + authorizedSite)
            .toString();
    }


    /**
     * Creates an instance of defaultAuthorizedSites.
     */
    public DefaultAuthorizedSites() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicecloudaccess/cloudaccesses/cloudaccess/DefaultAuthorizedSites.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicecloudaccess.cloudaccesses.cloudaccess;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicecloudaccess.cloudaccesses.cloudaccess.authorizedsites.AuthorizedSite;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of authorizedSites.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAuthorizedSites extends InnerModelObject implements AuthorizedSites {
    protected List<AuthorizedSite> authorizedSite;

    @Override
    public List<AuthorizedSite> authorizedSite() {
        return authorizedSite;
    }

    @Override
    public void authorizedSite(List<AuthorizedSite> authorizedSite) {
        this.authorizedSite = authorizedSite;
    }

    @Override
    public void addToAuthorizedSite(AuthorizedSite addTo) {
        if (authorizedSite == null) {
            authorizedSite = new ArrayList<>();
        }
        authorizedSite.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(authorizedSite);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAuthorizedSites) {
            DefaultAuthorizedSites other = (DefaultAuthorizedSites) obj;
            return
                Objects.deepEquals(authorizedSite, other.authorizedSite);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("authorizedSite=" + authorizedSite)
            .toString();
    }


    /**
     * Creates an instance of defaultAuthorizedSites.
     */
    public DefaultAuthorizedSites() {
    }

}
